==> onos-yang-runtime-2.2.0-sources.jar: org/onosproject/yang/gen/v1/hello/rev20150105/hello/hellosecond/DefaultHelloSecondOutput.java <==
/*
 * Copyright 2017-present Open Networking Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.onosproject.yang.gen.v1.hello.rev20150105.hello.hellosecond;

import java.util.BitSet;
import java.util.Objects;
import java.util.StringJoiner;
import org.onosproject.yang.model.InnerModelObject;

/**
 * Represents the implementation of helloSecondOutput.
 */
public class DefaultHelloSecondOutput extends InnerModelObject implements HelloSecondOutput {
    protected byte[] greeting;
    protected BitSet valueLeafFlags = new BitSet();

    @Override
    public byte[] greeting() {
        return greeting;
    }

    @Override
    public BitSet valueLeafFlags() {
        return valueLeafFlags;
    }

    @Override
    public void greeting(byte[] greeting) {
        valueLeafFlags.set(LeafIdentifier.GREETING.getLeafIndex());
        this.greeting = greeting;
    }

    @Override
    public int hashCode() {
        return Objects.hash(greeting, valueLeafFlags);
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj instanceof DefaultHelloSecondOutput) {
            DefaultHelloSecondOutput other = (DefaultHelloSecondOutput) obj;
            return
                Objects.equals(greeting, other.greeting) &&
                Objects.equals(valueLeafFlags, other.valueLeafFlags);
        }
        return false;
    }

    @Override
    public String toString() {
        return new StringJoiner(", ", getClass().getSimpleName() +"{", "}")
            .add("greeting=" + greeting)
            .add("valueLeafFlags=" + valueLeafFlags)
            .toString();
    }


    /**
     * Creates an instance of defaultHelloSecondOutput.
     */
    public DefaultHelloSecondOutput() {
    }


    @Override
    public boolean isLeafValueSet(LeafIdentifier leaf) {
        return valueLeafFlags.get(leaf.getLeafIndex());
    }

}

==> onos-yang-runtime-2.3.1-sources.jar: org/onosproject/yang/gen/v1/hello/rev20150105/hello/hellosecond/DefaultHelloSecondOutput.java <==
/*
 * Copyright 2017-present Open Networking Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.onosproject.yang.gen.v1.hello.rev20150105.hello.hellosecond;

import java.util.BitSet;
import java.util.Objects;
import java.util.StringJoiner;
import org.onosproject.yang.model.InnerModelObject;

/**
 * Represents the implementation of helloSecondOutput.
 */
public class DefaultHelloSecondOutput extends InnerModelObject implements HelloSecondOutput {
    protected byte[] greeting;
    protected BitSet valueLeafFlags = new BitSet();

    @Override
    public byte[] greeting() {
        return greeting;
    }

    @Override
    public BitSet valueLeafFlags() {
        return valueLeafFlags;
    }

    @Override
    public void greeting(byte[] greeting) {
        valueLeafFlags.set(LeafIdentifier.GREETING.getLeafIndex());
        this.greeting = greeting;
    }

    @Override
    public int hashCode() {
        return Objects.hash(greeting, valueLeafFlags);
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj instanceof DefaultHelloSecondOutput) {
            DefaultHelloSecondOutput other = (DefaultHelloSecondOutput) obj;
            return
                Objects.deepEquals(greeting, other.greeting) &&
                Objects.deepEquals(valueLeafFlags, other.valueLeafFlags);
        }
        return false;
    }

    @Override
    public String toString() {
        return new StringJoiner(", ", getClass().getSimpleName() +"{", "}")
            .add("greeting=" + greeting)
            .add("valueLeafFlags=" + valueLeafFlags)
            .toString();
    }


    /**
     * Creates an instance of defaultHelloSecondOutput.
     */
    public DefaultHelloSecondOutput() {
    }


    @Override
    public boolean isLeafValueSet(LeafIdentifier leaf) {
        return valueLeafFlags.get(leaf.getLeafIndex());
    }

}
